@@ -26,6 +26,8 @@
 
 #include <libgnomevfs/gnome-vfs-file-info.h>
 
+G_BEGIN_DECLS
+
 /* Xfer options.  
  * FIXME bugzilla.eazel.com 1205:
  * Split these up into xfer options and xfer actions
@@ -42,7 +44,8 @@ typedef enum {
 	GNOME_VFS_XFER_NEW_UNIQUE_DIRECTORY = 1 << 7,
 	GNOME_VFS_XFER_REMOVESOURCE = 1 << 8,
 	GNOME_VFS_XFER_USE_UNIQUE_NAMES = 1 << 9,
-	GNOME_VFS_XFER_LINK_ITEMS = 1 << 10
+	GNOME_VFS_XFER_LINK_ITEMS = 1 << 10,
+	GNOME_VFS_XFER_FOLLOW_LINKS_RECURSIVE = 1 << 11
 } GnomeVFSXferOptions;
 
 /* Progress status, to be reported to the caller of the transfer operation.  */
@@ -68,14 +71,25 @@ typedef enum {
 	GNOME_VFS_XFER_OVERWRITE_MODE_SKIP = 3
 } GnomeVFSXferOverwriteMode;
 
-/* This defines the actions to perform before a file is being overwritten
-   (i.e., these are the answers that can be given to a replace query).  */
+/**
+ * GnomeVFSXferOverwriteAction:
+ * @GNOME_VFS_XFER_OVERWRITE_ACTION_ABORT: abort the transfer
+ * @GNOME_VFS_XFER_OVERWRITE_ACTION_REPLACE: replace the existing file
+ * @GNOME_VFS_XFER_OVERWRITE_ACTION_REPLACE_ALL: replace the existing file, and all future files
+ * without prompting the callback.
+ * @GNOME_VFS_XFER_OVERWRITE_ACTION_SKIP: don't copy over the existing file
+ * @GNOME_VFS_XFER_OVERWRITE_ACTION_SKIP_ALL: don't copy over the existing file, and all future
+ * files without prompting the callback.
+ * 
+ * This defines the actions to perform before a file is being overwritten
+ * (i.e., these are the answers that can be given to a replace query).  
+ **/
 typedef enum {
 	GNOME_VFS_XFER_OVERWRITE_ACTION_ABORT = 0,
 	GNOME_VFS_XFER_OVERWRITE_ACTION_REPLACE = 1,
 	GNOME_VFS_XFER_OVERWRITE_ACTION_REPLACE_ALL = 2,
 	GNOME_VFS_XFER_OVERWRITE_ACTION_SKIP = 3,
-	GNOME_VFS_XFER_OVERWRITE_ACTION_SKIP_ALL = 4,
+	GNOME_VFS_XFER_OVERWRITE_ACTION_SKIP_ALL = 4
 } GnomeVFSXferOverwriteAction;
 
 typedef enum {
@@ -84,7 +98,7 @@ typedef enum {
 	GNOME_VFS_XFER_ERROR_MODE_ABORT = 0,
 	/* Invoke the progress callback with a
 	   `GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR' status code. */
-	GNOME_VFS_XFER_ERROR_MODE_QUERY = 1,
+	GNOME_VFS_XFER_ERROR_MODE_QUERY = 1
 } GnomeVFSXferErrorMode;
 
 /* This defines the possible actions to be performed after an error has
@@ -190,6 +204,11 @@ typedef struct {
 	 * traversing directories. Used by metadata copying.
 	 */
 
+	/* Reserved for future expansions to GnomeVFSXferProgressInfo
+	 * without having to break ABI compatibility */
+	void *reserved1;
+	void *reserved2;
+
 } GnomeVFSXferProgressInfo;
 
 /* This is the prototype for functions called during a transfer operation to
@@ -240,6 +259,13 @@ typedef struct GnomeVFSProgressCallbackState {
 
 	/* Period at which the update_callback will be called. */
 	gint64 update_callback_period;
+
+
+	/* Reserved for future expansions to GnomeVFSProgressCallbackState
+	 * without having to break ABI compatibility */
+	void *reserved1;
+	void *reserved2;
+
 } GnomeVFSProgressCallbackState;
 
 GnomeVFSResult gnome_vfs_xfer_uri_list    (const GList                  *source_uri_list,
@@ -262,4 +288,6 @@ GnomeVFSResult gnome_vfs_xfer_delete_list (const GList                  *source_
 					   GnomeVFSXferProgressCallback  progress_callback,
 					   gpointer                      data);
 
+G_END_DECLS
+
 #endif /* GNOME_VFS_XFER_H */
